==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/tripcore/TRIPRoutes.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

#include "TRIPRoutes.hxx"
#include "TRIPUtil.hxx"
#include "cpLog.h"

TRIPRoutes::TRIPRoutes(TRIPAddrFamily aFamily ,
                   TRIPAppProto protocol , const TRIPData& data)
{
    _addrHdr = new TRIPRouteHdr(aFamily, protocol);
    _data = new TRIPData("");
    processAddress(*_addrHdr, data.getData(), data.length());
    _length = _data->length();
}


TRIPRoutes::TRIPRoutes(const TRIPRouteHdr& hdr, const TRIPData& data)
{
    _addrHdr = new TRIPRouteHdr(hdr);
    _data = new TRIPData("");
    processAddress(*_addrHdr, data.getData(), data.length());
    _length = _data->length();
}

TRIPRoutes::TRIPRoutes(const char* buf) throw(TRIPBadDataException&)
{
    _addrHdr = new TRIPRouteHdr(buf);
    u_int16_t  len;
    memcpy(&len, buf+_addrHdr->getLength(), 2);
    _length = ntohs(len); 
    processAddress(*_addrHdr, buf+_addrHdr->getLength()+2, _length);
}

void
TRIPRoutes::processAddress(const TRIPRouteHdr& hdr, const char* buf, int len)
{
    switch(hdr.getAddrFamily())
    {
        case TRIP_ADDR_POTS:
        {
            _data = new TRIPPotsNumber(buf, len);
        }
        break;
        case TRIP_ADDR_ROUTING_NUM:
        {
            _data = new TRIPRoutingNumber(buf, len);
        }
        break;
        default:
        {
            cpLog(LOG_ALERT, "Unsupported Address family");
        }
        break;
    }
}

TRIPRoutes::TRIPRoutes(const TRIPRoutes& other) 
{
    copyObj(other);    
}

TRIPRoutes& 
TRIPRoutes::operator=(const TRIPRoutes& other)
{
    if(this != &other)
    {
        copyObj(other);    
    }
    return (*this);
}

void
TRIPRoutes::copyObj(const TRIPRoutes& other)
{
    _addrHdr = other._addrHdr;
    _length = other._length;
    _data = other._data;
}

void 
TRIPRoutes::writeData(int id) const throw(VNetworkException&)
{
    u_int16_t  len;

    _addrHdr->writeData(id);
    len = htons(_length);
    TRIPUtil::writeData(id, &len, 2);
    if(_data->length())
    {
        TRIPUtil::writeData(id, _data->getData(), _data->length());
    }
}

u_int16_t 
TRIPRoutes::getLength() const
{
    ///Data length + 6 bytes holding the addrheader + length
    return(6+_length);
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/tripcore/TRIPRoutes.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

#include <netinet/in.h>

#include "TRIPRoutes.hxx"
#include "TRIPUtil.hxx"
#include "TRIPPotsNumber.hxx"
#include "TRIPRoutingNumber.hxx"
#include "TRIPErrorHandler.hxx"
#include "cpLog.h"

static const int ROUTE_MIN_LENGTH=6;

TRIPRoutes::TRIPRoutes(TRIPAddrFamily aFamily ,
                   TRIPAppProto protocol , const TRIPData& data)
{
    _routeHdr = new TRIPRouteHdr(aFamily, protocol);
    processAddress(*_routeHdr, data.getData(), data.length());
    _length = _data->length();
}


TRIPRoutes::TRIPRoutes(const TRIPRouteHdr& hdr, const TRIPData& data)
{
    _routeHdr = new TRIPRouteHdr(hdr);
    processAddress(*_routeHdr, data.getData(), data.length());
    _length = _data->length();
}

TRIPRoutes::TRIPRoutes(const char* buf) throw(TRIPBadDataException&)
{
    assert(buf);
    _routeHdr = new TRIPRouteHdr(buf);
    u_int16_t  len;
    memcpy(&len, buf+_routeHdr->getLength(), 2);
    _length = ntohs(len); 
    processAddress(*_routeHdr, buf+_routeHdr->getLength()+2, _length);
}

void
TRIPRoutes::processAddress(const TRIPRouteHdr& hdr, const char* buf, int len)
{
    switch(hdr.getAddrFamily())
    {
        case TRIP_ADDR_POTS:
        {
            _data = new TRIPPotsNumber(buf, len);
        }
        break;
        case TRIP_ADDR_ROUTING_NUM:
        {
            _data = new TRIPRoutingNumber(buf, len);
        }
        break;
        default:
        {
            throw TRIPBadDataException("Unsupported Address family", 
                                           __FILE__,__LINE__, TRIP_ERR_UPDATE, U_INVALID_ATTR);
        }
        break;
    }
}

TRIPRoutes::TRIPRoutes(const TRIPRoutes& other) 
{
    copyObj(other);    
}

TRIPRoutes& 
TRIPRoutes::operator=(const TRIPRoutes& other)
{
    if(this != &other)
    {
        copyObj(other);    
    }
    return (*this);
}

void
TRIPRoutes::copyObj(const TRIPRoutes& other)
{
    _routeHdr = other._routeHdr;
    _length = other._length;
    _data = other._data;
}

void 
TRIPRoutes::writeData(int id) const throw(VNetworkException&)
{
    u_int16_t  len;

    _routeHdr->writeData(id);
    len = htons(_length);
    TRIPUtil::writeData(id, &len, 2);
    if(_data->length())
    {
        TRIPUtil::writeData(id, _data->getData(), _data->length());
    }
}

u_int16_t 
TRIPRoutes::getLength() const
{
    ///Data length + 6 bytes holding the addrheader + length
    return(ROUTE_MIN_LENGTH+_length);
}


bool 
TRIPRoutes::operator==(const TRIPRoutes& other)
{
    return ((getAppProtocol() == other.getAppProtocol())&&
      (getAddrFamily() == other.getAddrFamily()) &&
       (getPrefix() == other.getPrefix())); 
      
}
